==> igniteui-react-charts-16.6.8.tgz: package/ES5/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(PercentageVolumeOscillatorIndicator, _super);
    function PercentageVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentageVolumeOscillatorIndicator.prototype.get_p5 = function () {
        return new PercentageVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.get_qi = function () {
        return PercentageVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qr));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.qd = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qq));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.qq, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.qa = function () {
        return this.longPeriod;
    };
    PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.qr = StrategyBasedIndicator.qp(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.qq = StrategyBasedIndicator.ql(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { PercentageVolumeOscillatorIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(PercentageVolumeOscillatorIndicator, _super);
    function PercentageVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentageVolumeOscillatorIndicator.prototype.get_qc = function () {
        return new PercentageVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.get_qp = function () {
        return PercentageVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qy));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.qk = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qx));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.qx, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.qh = function () {
        return this.longPeriod;
    };
    PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.qy = StrategyBasedIndicator.qw(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.qx = StrategyBasedIndicator.qs(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { PercentageVolumeOscillatorIndicator };
